==> squidwall-0.4a.tar.bz2: squidwall-0.4a/check_redirect.c <==
#include "squidwall.h"

/**
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/**
 * redirecting via definitions from /etc/squidwall/redirects
 */

int check_redirect(void)
{
	struct squidwall_string *string;
	struct list_head *l;
	char *test_url;
	stralloc sa;

	test_url=squid_url;
	if (str_start(test_url, "ftp://")) { test_url+=6; }
	if (str_start(test_url, "http://"))  { test_url+=7; }
	if (str_start(test_url, "https://")) { test_url+=8; }
	
	/**
	 * remove trailing slashes, they can not be created @filesystem
	 * in /etc/squidwall/redirects/
	 */

	stralloc_init(&sa);
	if (!stralloc_copys(&sa, test_url)) die_nomem();
	if (sa.s[sa.len-1] == '/') sa.s[sa.len-1]=0;
	sa.s[sa.len]=0;

	list_for_each(l, &redirects) {
		string = list_entry(l, struct squidwall_string, list);
		if (str_equal(sa.s, string->filename.s)) {
			/* we redirect via "302:site\n" */
			if (!stralloc_copys(&redirsite, "302:")) die_nomem();
			if (!stralloc_cat(&redirsite, &string->strings)) die_nomem();
			debug_s(DEBUG_CHECK_REDIR, "@check_redirect: redirect!");
			stralloc_free(&sa);
			return 1;
		}

	}

	debug_s(DEBUG_CHECK_REDIR, "@check_redirect: nothing!");
	stralloc_free(&sa);

	return 0;
}

==> squidwall-0.5a-06.tar.bz2: squidwall-0.5a-06/check_redirect.c <==

/**
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * debug section: 16 (redirecting)
 */

#include "squidwall.h"

/**
 * redirecting via definitions from /etc/squidwall/redirects
 */
int check_redirect(request_t *r)
{
	struct squidwall_string *string;
	struct list_head *l;
	stralloc sa;

	/**
	 * remove trailing slashes, they can not be created @filesystem
	 * in /etc/squidwall/redirects/
	 */

	stralloc_init(&sa);
	if (!stralloc_copys(&sa, r->url_host.s)) die_nomem();
	if (sa.s[sa.len-1] == '/') sa.s[sa.len-1]=0;
	sa.s[sa.len]=0;

	list_for_each(l, &redirects) {
		string = list_entry(l, struct squidwall_string, list);
		if (str_equal(sa.s, string->filename.s)) {
			/* we redirect via "302:site\n" */
			if (!stralloc_copys(&r->redirsite, "302:")) die_nomem();
			if (!stralloc_cat(&r->redirsite, &string->strings)) die_nomem();
			debug(12,3, "@check_redirect: redirect! (%S -> %S)",
				&sa, &string->strings);
			stralloc_free(&sa);
			return 1;
		}
	}

	debug(12,3, "@check_redirect: nothing!");
	stralloc_free(&sa);

	return 0;
}
